Package: RNAmodR.RiboMethSeq
Type: Package
Title: Detection of 2'-O methylations by RiboMethSeq
Version: 1.27.0
Date: 2025-09-25
Authors@R: c(person("Felix G.M.", 
                    "Ernst", 
                    email = "felix.gm.ernst@outlook.com", 
                    role = c("aut", "cre"),
                    comment = c(ORCID = "0000-0001-5064-0928")),
             person("Denis L.J.", 
                    "Lafontaine", 
                    email = "denis.lafontaine@ulb.ac.be", 
                    role = c("ctb", "fnd")))
Description: RNAmodR.RiboMethSeq implements the detection of 2'-O methylations
    on RNA from experimental data generated with the RiboMethSeq protocol. 
    The package builds on the core functionality of the RNAmodR package to
    detect specific patterns of the modifications in high throughput sequencing
    data.
biocViews: Software, WorkflowStep, Visualization, Sequencing
License: Artistic-2.0
Encoding: UTF-8
LazyData: false
Depends: R (>= 4.0), RNAmodR (>= 1.5.3)
Imports: methods, S4Vectors, BiocGenerics, IRanges, GenomicRanges, Gviz
Suggests: BiocStyle, knitr, rmarkdown, testthat, rtracklayer, Seqinfo,
        RNAmodR.Data
Collate: 'RNAmodR.RiboMethSeq.R' 'Modifier-RiboMethSeq-class.R'
        'Modifier-RiboMethSeq-viz.R'
VignetteBuilder: knitr
RoxygenNote: 7.3.3
BugReports: https://github.com/FelixErnst/RNAmodR.RiboMethSeq/issues
URL: https://github.com/FelixErnst/RNAmodR.RiboMethSeq
git_url: https://git.bioconductor.org/packages/RNAmodR.RiboMethSeq
git_branch: devel
git_last_commit: 6f2e754
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 00:45:11 UTC; biocbuild
Author: Felix G.M. Ernst [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-5064-0928>),
  Denis L.J. Lafontaine [ctb, fnd]
Maintainer: Felix G.M. Ernst <felix.gm.ernst@outlook.com>
